package Mesos::Test::Executor;
use Mesos::Messages;
use Moo;
extends 'Mesos::Executor';

1;
